<no title> — CALCEPH - Fortran 77/90/95 language 3.4.1 documentation

    integer*8 peph
    integer j, itarget, icenter, iframe
    real*8 firsttime, lasttime
    integer res

    res = f90calceph_open(peph, "example1.dat")
    if (res.eq.1) then
      do j=1, f90calceph_getpositionrecordcount(peph)
        res = f90calceph_getpositionrecordindex(peph,j,itarget, icenter, firsttime, lasttime, iframe)
        write (*,*) itarget, icenter, firsttime, lasttime, iframe
      enddo
      call f90calceph_close(peph)
    endif